import folium
from folium import plugins
import json
import os
import requests


# Function to load GeoJSON data from a file
def load_geojson(file_path):
    with open(file_path, "r") as file:
        return json.load(file)
         
# Create a base map with OpenStreetMap as the base layer
m = folium.Map(location=[47.486764493055716, 11.082565078247972], zoom_start=10)


# Add topographical map (OpenTopoMap)
topo_map = folium.TileLayer(
    tiles="https://{s}.tile.opentopomap.org/{z}/{x}/{y}.png",
    attr="OpenTopoMap",
    name="Topography",
    overlay=False,
).add_to(m)

# Add marker clusters for better visualization of multiple markers
marker_cluster_new = plugins.MarkerCluster(name="New stations").add_to(m)
marker_cluster_ren = plugins.MarkerCluster(name="Renewed stations").add_to(m)
marker_cluster_exs = plugins.MarkerCluster(name="Existing stations").add_to(m)

# Create a custom layer control without the macro_element
layer_control = folium.LayerControl(collapsed=False, autoZIndex=False)


target = "_blank"
# Add markers from GeoJSON data to the cluster

station_file = 'src/stations.geojson'
geojson_data = json.load(open(station_file))

for feature in geojson_data["features"]:
    type = feature["properties"].get("type", "")
    coordinates = feature["geometry"]["coordinates"]
    name = feature["properties"].get("name", "")
    description = feature["properties"].get("description", "")
    instrumentation = feature["properties"].get("instrumentation", "")
    link = feature["properties"].get("link", "")

    # Enlarge the popup window by setting max_width
    popup_content = f"<b>{name}</b><br>Info: {description}<br>Planned instruments: {instrumentation}<br><a href={link} target={target}>Link</a>"
            
    if type == "new":
        folium.Marker(location=coordinates, icon=folium.Icon(color='green'), popup=folium.Popup(popup_content, max_width=300)).add_to(marker_cluster_new)
    elif type == "renewed":
        folium.Marker(location=coordinates, icon=folium.Icon(color='orange'), popup=folium.Popup(popup_content, max_width=300)).add_to(marker_cluster_ren)
    elif type == "existing":
        folium.Marker(location=coordinates,  icon=folium.Icon(color='blue'), popup=folium.Popup(popup_content, max_width=300)).add_to(marker_cluster_exs)    

# Add Layer Control for switching between base layers
layer_control.add_to(m)

# Save the map to an HTML file
m.save("templates/index.html")
